@@ -10,6 +10,8 @@ import random
 import logging
 logger = logging.getLogger("main")
 
+import pytz
+
 timeservers=["nist1.uccaribe.edu", "nist1-ny.WiTime.net", "time-a.nist.gov", "time-b.nist.gov", "nist1-dc.WiTime.net", "nist1.aol-va.symmetricom.com", "nist1.columbiacountyga.gov", "nist.expertsmi.com", "nist.netservicesgroup.com", "time-a.timefreq.bldrdoc.gov", "time-c.timefreq.bldrdoc.gov", "time.nist.gov", "utcnist.colorado.edu", "utcnist2.colorado.edu", "ntp-nist.ldsbc.edu", "time-nw.nist.gov", "nist1.aol-ca.symmetricom.com", "nist1.symmetricom.com", "nist1-sj.WiTime.net", "nist1-la.WiTime.net"]
 random.shuffle(timeservers)
 
@@ -64,7 +66,8 @@ def _getTimeOffsetCallback2( data, server ):
         int(data[13:15]),
         int(data[16:18]),
         int(data[19:21]),
-        int(data[22:23]) )
+        int(data[22:23]),
+        tzinfo=pytz.utc )
     
     offset = time.mktime( t.timetuple() ) - time.time()
     return offset
